package org.apache.bcel.classfile;

import java.io.DataInput;
import java.io.DataOutputStream;
import java.io.IOException;
import java.util.Arrays;
import java.util.Iterator;
import java.util.stream.Stream;

/* loaded from: org_apache_bcel_classfile.jar:org/apache/bcel/classfile/MethodParameters.class */
public class MethodParameters extends Attribute implements Iterable<MethodParameter> {
    private static final MethodParameter[] EMPTY_METHOD_PARAMETER_ARRAY = new MethodParameter[0];
    private MethodParameter[] parameters;

    /* JADX INFO: Access modifiers changed from: package-private */
    public MethodParameters(int nameIndex, int length, DataInput input, ConstantPool constantPool) throws IOException {
        super((byte) 21, nameIndex, length, constantPool);
        this.parameters = EMPTY_METHOD_PARAMETER_ARRAY;
        int parameterCount = input.readUnsignedByte();
        this.parameters = new MethodParameter[parameterCount];
        for (int i = 0; i < parameterCount; i++) {
            this.parameters[i] = new MethodParameter(input);
        }
    }

    @Override // org.apache.bcel.classfile.Attribute, org.apache.bcel.classfile.Node
    public void accept(Visitor v) {
        v.visitMethodParameters(this);
    }

    @Override // org.apache.bcel.classfile.Attribute
    public Attribute copy(ConstantPool constantPool) {
        MethodParameters c = (MethodParameters) clone();
        c.parameters = new MethodParameter[this.parameters.length];
        Arrays.setAll(c.parameters, i -> {
            return this.parameters[i].copy();
        });
        c.setConstantPool(constantPool);
        return c;
    }

    @Override // org.apache.bcel.classfile.Attribute
    public void dump(DataOutputStream file) throws IOException {
        super.dump(file);
        file.writeByte(this.parameters.length);
        for (MethodParameter parameter : this.parameters) {
            parameter.dump(file);
        }
    }

    public MethodParameter[] getParameters() {
        return this.parameters;
    }

    @Override // java.lang.Iterable
    public Iterator<MethodParameter> iterator() {
        return Stream.of((Object[]) this.parameters).iterator();
    }

    public void setParameters(MethodParameter[] parameters) {
        this.parameters = parameters;
    }
}
